@@ -1,5 +1,6 @@
 import asyncio
 import glob
+import json
 import os
 import time
 from asyncio import CancelledError
@@ -104,6 +105,8 @@ class AliasedGroup(click.Group):
 def cli():
     """
     OmegaCloud: One-click platform for AI-apps deployment
+
+    CLI version: v.0.1.6 / for update: pip install --upgrade omegacloud-cli
     """
     pass
 
@@ -203,7 +206,7 @@ async def login_flow():
 
     save_config({"apikey": token})
     console.print("[green]Token saved successfully[/]")
-    console.print("You can update your token anytime by running: [bold]omega login[/]")
+    console.print("Note: You can update your token anytime by running: [bold]omega login[/]")
     console.print()
 
 
@@ -325,111 +328,136 @@ async def sync_flow(status: Status, sync_type: str, operations: str = "upload+do
         # Add a blank line to create separation
         console.print()
 
-        # Execute sync operations with Progress
-        with Progress() as progress:
-            # Process downloads first if stopping
-            if to_client_count > 0 and choice in ["all", "download"]:
-                console.print("Downloading files from server...")
+        batch_size = 15
 
-                # Create individual tasks for each download
-                download_tasks = {}
-                for file_meta in sync_result.to_client:
-                    # Create a task with the file size as the total
-                    download_task_id = progress.add_task(
-                        f"[green]Downloading {file_meta.path}[/]", total=file_meta.size, completed=0
-                    )
-                    download_tasks[file_meta.path] = download_task_id
+        # Process downloads first if stopping
+        if to_client_count > 0 and choice in ["all", "download"]:
+            files_from = 0  # inclusive
+            files_to = min(len(sync_result.to_client), batch_size)  # exclusive
 
-                # Process each download
-                for file_meta in sync_result.to_client:
-                    download_task_id = download_tasks[file_meta.path]
-                    download_callback = make_progress_callback(progress, download_task_id)
+            while files_from < files_to:
+                console.print(
+                    f"[green]Downloading files from server [{files_from + 1}-{files_to} / {len(sync_result.to_client)}]...[/]"
+                )
 
-                    success, error = await api.download_file_api(
-                        sync_type,
-                        sync_id,
-                        file_meta.path,
-                        storage_path,
-                        storage_name,
-                        download_callback,
-                    )
-
-                    if success:
-                        progress.update(
-                            download_task_id,
-                            completed=file_meta.size,
-                            description=f"[green]Completed: {file_meta.path}[/]",
+                # Execute sync operations with Progress
+                with Progress() as progress:
+                    # Create individual tasks for each download
+                    download_tasks = {}
+                    for file_meta in sync_result.to_client[files_from:files_to]:
+                        # Create a task with the file size as the total
+                        download_task_id = progress.add_task(
+                            f"[green]Downloading {file_meta.path}[/]",
+                            total=file_meta.size,
+                            completed=0,
                         )
-                    elif error:
-                        sync_error = True
-                        console.print(f"[red]Failed download {file_meta.path}: {str(error)}[/]")
-                        progress.update(
-                            download_task_id,
-                            completed=file_meta.size,
-                            description=f"[red]Failed: {file_meta.path}",
-                        )
-                    else:
-                        sync_error = True
-                        console.print(f"[red]Failed download {file_meta.path}[/]")
-                        progress.update(
-                            download_task_id,
-                            completed=file_meta.size,
-                            description=f"[red]Failed: {file_meta.path}",
+                        download_tasks[file_meta.path] = download_task_id
+
+                    # Process each download
+                    for file_meta in sync_result.to_client[files_from:files_to]:
+                        download_task_id = download_tasks[file_meta.path]
+                        download_callback = make_progress_callback(progress, download_task_id)
+
+                        success, error = await api.download_file_api(
+                            sync_type,
+                            sync_id,
+                            file_meta.path,
+                            storage_path,
+                            storage_name,
+                            download_callback,
                         )
 
-            # Process uploads first if starting
-            if to_server_count > 0 and choice in ["all", "upload"]:
-                console.print("[blue]Uploading files to server...[/]")
+                        if success:
+                            progress.update(
+                                download_task_id,
+                                completed=file_meta.size,
+                                description=f"[green]Completed: {file_meta.path}[/]",
+                            )
+                        elif error:
+                            sync_error = True
+                            console.print(f"[red]Failed download {file_meta.path}: {str(error)}[/]")
+                            progress.update(
+                                download_task_id,
+                                completed=file_meta.size,
+                                description=f"[red]Failed: {file_meta.path}",
+                            )
+                        else:
+                            sync_error = True
+                            console.print(f"[red]Failed download {file_meta.path}[/]")
+                            progress.update(
+                                download_task_id,
+                                completed=file_meta.size,
+                                description=f"[red]Failed: {file_meta.path}",
+                            )
+                files_from = files_to
+                files_to = min(files_from + batch_size, len(sync_result.to_client))
 
-                # Create individual tasks for each upload
-                upload_tasks = {}
-                for file_meta in sync_result.to_server:
-                    # Create a task with the file size as the total
-                    upload_task_id = progress.add_task(
-                        f"[blue]Uploading {file_meta.path}", total=file_meta.size, completed=0
-                    )
-                    upload_tasks[file_meta.path] = upload_task_id
+        # Process uploads first if starting
+        if to_server_count > 0 and choice in ["all", "upload"]:
+            files_from = 0  # inclusive
+            files_to = min(len(sync_result.to_server), batch_size)  # exclusive
 
-                # Process each upload
-                for file_meta in sync_result.to_server:
-                    upload_task_id = upload_tasks[file_meta.path]
-                    upload_callback = make_progress_callback(progress, upload_task_id)
+            while files_from < files_to:
+                console.print(
+                    f"[blue]Uploading files to server [{files_from + 1}-{files_to} / {len(sync_result.to_server)}]...[/]"
+                )
 
-                    success, error = await api.upload_file_api(
-                        sync_type,
-                        sync_id,
-                        file_meta.path,
-                        storage_path,
-                        storage_name,
-                        upload_callback,
-                    )
-
-                    if success:
-                        progress.update(
-                            upload_task_id,
-                            completed=file_meta.size,
-                            description=f"[blue]Completed: {file_meta.path}",
+                # Execute sync operations with Progress
+                with Progress() as progress:
+                    # Create individual tasks for each upload
+                    upload_tasks = {}
+                    for file_meta in sync_result.to_server[files_from:files_to]:
+                        # Create a task with the file size as the total
+                        upload_task_id = progress.add_task(
+                            f"[blue]Uploading {file_meta.path}",
+                            total=file_meta.size,
+                            completed=0,
                         )
-                    elif error:
-                        sync_error = True
-                        console.print(f"[red]Failed upload {file_meta.path}: {str(error)}[/]")
-                        progress.update(
-                            upload_task_id,
-                            completed=file_meta.size,
-                            description=f"[red]Failed: {file_meta.path}",
-                        )
-                    else:
-                        sync_error = True
-                        console.print(f"[red]Failed upload {file_meta.path}[/]")
-                        progress.update(
-                            upload_task_id,
-                            completed=file_meta.size,
-                            description=f"[red]Failed: {file_meta.path}",
+                        upload_tasks[file_meta.path] = upload_task_id
+
+                    # Process each upload
+                    for file_meta in sync_result.to_server[files_from:files_to]:
+                        upload_task_id = upload_tasks[file_meta.path]
+                        upload_callback = make_progress_callback(progress, upload_task_id)
+
+                        success, error = await api.upload_file_api(
+                            sync_type,
+                            sync_id,
+                            file_meta.path,
+                            storage_path,
+                            storage_name,
+                            upload_callback,
                         )
 
+                        if success:
+                            progress.update(
+                                upload_task_id,
+                                completed=file_meta.size,
+                                description=f"[blue]Completed: {file_meta.path}",
+                            )
+                        elif error:
+                            sync_error = True
+                            console.print(f"[red]Failed upload {file_meta.path}: {str(error)}[/]")
+                            progress.update(
+                                upload_task_id,
+                                completed=file_meta.size,
+                                description=f"[red]Failed: {file_meta.path}",
+                            )
+                        else:
+                            sync_error = True
+                            console.print(f"[red]Failed upload {file_meta.path}[/]")
+                            progress.update(
+                                upload_task_id,
+                                completed=file_meta.size,
+                                description=f"[red]Failed: {file_meta.path}",
+                            )
+                    files_from = files_to
+                    files_to = min(files_from + batch_size, len(sync_result.to_server))
+
     synced = not sync_error
 
     console.print("[green]Sync completed![/]")
+    console.print("Note: You can sync your files anytime by running: [bold]omega sync[/]")
     console.print()
     status.start()
     return synced
@@ -627,29 +655,140 @@ async def schedule_flow() -> str:
     save_config({"job_schedule": job_schedule})
 
     # Load task.sh script for user display
-    script = load_script("task.sh")
-    task_command = " && ".join(script) if script else "python main.py"
+    # script = load_script("task.sh")
+    # task_command = "; ".join(script) if script else "python main.py"
 
-    # Ask user to input task run command
-    task_command = await inquirer.text(
-        message="Enter command to run your task:",
-        style=style,
-        default=task_command,
-    ).execute_async()
+    # # Ask user to input task run command
+    # task_command = await inquirer.text(
+    #     message="Enter command to run your task:",
+    #     style=style,
+    #     default=task_command,
+    # ).execute_async()
 
-    # Split command by && and clean up whitespace
-    commands = [cmd.strip() for cmd in task_command.split("&&")]
-    save_script("task.sh", commands)
+    # # Split command by ; and clean up whitespace
+    # commands = [cmd.strip() for cmd in task_command.split(";")]
+    # save_script("task.sh", commands)
 
     return job_schedule
 
 
+async def commands_flow(job_type: JobTypeEnum):
+    """Detect the job type based on the files in the current directory.
+
+    Returns:
+        JobTypeEnum: The job type.
+    """
+
+    # Load existing commands
+    setup_commands = load_script("setup.sh")
+    build_commands = []
+    run_commands = []
+    task_commands = []
+
+    job_schedule = load_config("job_schedule")
+
+    # Needs for API
+    # API not schedule: build, run
+    # API + schedule: build, run, task
+    # JOB not schedule: build, run
+    # JOB + schedule: build, task
+    # LAB: nothing
+
+    if job_type in [JobTypeEnum.API, JobTypeEnum.JOB]:
+        # Asking for build commands
+        build_commands = load_script("build.sh")
+        if not build_commands:
+            build_commands = autodetect_build_commands()
+        build_command = "; ".join(build_commands)
+        framework = autodetect_framework()
+        if framework == "node":
+            console.print()
+            console.print(
+                "[bold]Important![/] Build your node application locally before running it on Omega Cloud!"
+            )
+
+        # Ask user to input app build command
+        build_command = await inquirer.text(
+            message="Enter command to install dependencies:",
+            style=style,
+            default=build_command,
+        ).execute_async()
+        build_commands = [cmd.strip() for cmd in build_command.split(";")]
+
+    if (job_type in JobTypeEnum.API) or (not job_schedule):
+        # Asking for run commands for API/WEB applications or JOB without schedule (one-time job)
+        run_commands = load_script("run.sh")
+        if not run_commands:
+            run_commands = await autodetect_run_commands()
+        run_command = "; ".join(run_commands)
+
+        # Ask user to input app run command
+        if job_type in JobTypeEnum.API:
+            console.print()
+            console.print("[bold]Important![/] Run your API/WEB on [bold]8008[/] port!")
+
+        if framework == "node":
+            node_scripts = get_node_scripts()
+            # select script
+            choices = [Choice(value=k, name=f"{k}: {v}") for k, v in node_scripts.items()]
+            run_command = await inquirer.select(
+                message="Select script to run your application:",
+                choices=choices,
+                default=run_commands[0] if run_commands else choices[0].value,
+            ).execute_async()
+            run_commands = [run_command]
+
+        else:
+            run_command = await inquirer.text(
+                message="Enter command to run your application:",
+                style=style,
+                default=run_command,
+            ).execute_async()
+            run_commands = [cmd.strip() for cmd in run_command.split(";")]
+
+    if job_schedule:
+        # Asking for task commands for scheduled jobs
+        task_commands = load_script("task.sh")
+        if not task_commands:
+            task_commands = autodetect_task_commands()
+        task_command = "; ".join(task_commands)
+
+        # Ask user to input app run command
+        if framework == "node":
+            node_scripts = get_node_scripts()
+            # select script
+            choices = [Choice(value=k, name=f"{k}: {v}") for k, v in node_scripts.items()]
+            task_command = await inquirer.select(
+                message="Select script to run your scheduled task:",
+                choices=choices,
+                default=task_commands[0] if task_commands else choices[0].value,
+            ).execute_async()
+            task_commands = [task_command]
+
+        else:
+            task_command = await inquirer.text(
+                message="Enter command to run your scheduled task:",
+                style=style,
+                default=task_command,
+            ).execute_async()
+            task_commands = [cmd.strip() for cmd in task_command.split(";")]
+
+    if job_type == JobTypeEnum.LAB:
+        # For LAB type, create empty *.sh
+        pass
+
+    save_script("run.sh", run_commands)
+    save_script("build.sh", build_commands)
+    save_script("task.sh", task_commands)
+    save_script("setup.sh", setup_commands)
+
+
 async def type_flow() -> Tuple[JobTypeEnum, str]:
-    detected_job_type = await detect_job_type()
+    detected_job_type = await autodetect_job_type()
     job_type = load_config("job_type", detected_job_type.value)
 
     choices = [
-        Choice(value="api", name="API - Start an API-service (FastAPI/Flask)"),
+        Choice(value="api", name="API - Start an API-service (FastAPI/Flask/Node)"),
         Choice(value="job", name="Job - Run a program (one-time or periodically)"),
         Choice(value="lab", name="Lab - Launch a Lab (Jupyter Notebook)"),
     ]
@@ -666,6 +805,7 @@ async def type_flow() -> Tuple[JobTypeEnum, str]:
 
     elif job_type == "api":
         # Ask if user wants to add a schedule job for the API
+        current_schedule = load_config("job_schedule", None)
         choices = [
             Choice(value="no", name="No, just run API"),
             Choice(value="yes", name="Yes, add scheduled job"),
@@ -673,7 +813,7 @@ async def type_flow() -> Tuple[JobTypeEnum, str]:
         schedule_task = await inquirer.select(
             message="Would you like to add a scheduled job on top of your API?",
             choices=choices,
-            default=choices[0].value,
+            default="yes" if current_schedule else "no",
             style=style,
         ).execute_async()
 
@@ -686,17 +826,19 @@ async def type_flow() -> Tuple[JobTypeEnum, str]:
         job_schedule = ""
 
     save_config({"job_type": job_type, "job_schedule": job_schedule})
+    await commands_flow(JobTypeEnum(job_type))
 
     return JobTypeEnum(job_type), job_schedule
 
 
-async def storage_procedure():
+async def storage_flow():
     """Ask user to type storage names, separated by commas. return list of storage names."""
 
     # Read previous disk size from config file
     storage_list = load_config("storage", [])
 
     console.print("Shared storage is sync automatically between your jobs")
+    console.print("You can use shared storage located at: [bold]/tmp/<storage_name>[/]")
     storage_text = await inquirer.text(
         message="Enter shared storage names:",
         style=style,
@@ -707,6 +849,19 @@ async def storage_procedure():
     storage_list = [s.strip() for s in storage_list if s.strip()]
     save_config({"storage": storage_list})
 
+    if len(storage_list) > 1:
+        console.print(
+            "Shared storages are synced automatically between your applications every 5 minutes"
+        )
+        console.print("Shared storages are available for your application at:")
+    elif len(storage_list) > 0:
+        console.print(
+            "Shared storage is synced automatically between your applications every 5 minutes"
+        )
+        console.print("Shared storage is available for your application at:")
+    for storage in storage_list:
+        console.print(f" - /tmp/{storage}")
+
     return storage_list
 
 
@@ -739,13 +894,17 @@ async def size_flow(job_type: JobTypeEnum, force_config: bool = False):
 
         choices = [cpu_choice, gpu_choice]
 
-        compute_size = await inquirer.select(
+        compute_type = await inquirer.select(
             message=f"Select compute for your {title}:",
             choices=choices,
             default=choices[0].value,
             style=style,
         ).execute_async()
-        compute_size = f"{compute_size}-m"
+        compute_size = (
+            f"{compute_type}-m"
+            if not compute_size or not compute_size.startswith(compute_type)
+            else compute_size
+        )
 
     if job_type == JobTypeEnum.LAB or ("gpu" in compute_size):
         # Calculate max lengths for formatting
@@ -764,7 +923,7 @@ async def size_flow(job_type: JobTypeEnum, force_config: bool = False):
         compute_size = await inquirer.select(
             message=f"Select GPU size for your {title}:",
             choices=choices,
-            default=compute_size,
+            default=compute_size or choices[0].value,
             style=style,
         ).execute_async()
 
@@ -851,6 +1010,7 @@ async def config_flow(status: Status, force_config: bool = False) -> dict:
     Handles all configuration settings with strict validation.
     """
     config = {}
+    config_changed = False
 
     # Stop the status to avoid interference with questions
     status.stop()
@@ -861,6 +1021,7 @@ async def config_flow(status: Status, force_config: bool = False) -> dict:
         job_type, job_schedule = await type_flow()
         config["job_type"] = job_type.value
         config["job_schedule"] = job_schedule
+        config_changed = True
     else:
         job_schedule = load_config("job_schedule")
         config["job_type"] = job_type_value
@@ -885,7 +1046,7 @@ async def config_flow(status: Status, force_config: bool = False) -> dict:
     # Storage configuration
     storage_value = load_config("storage")
     if force_config or storage_value is None:
-        storage = await storage_procedure()
+        storage = await storage_flow()
         config["storage"] = storage
     else:
         config["storage"] = storage_value
@@ -912,6 +1073,13 @@ async def config_flow(status: Status, force_config: bool = False) -> dict:
     # Save the full configuration
     save_config(config)
 
+    if config_changed:
+        console.print("[green]Configuration saved successfully[/]")
+        console.print(
+            "Note: You can reconfigure your application by running: [bold]omega config[/]"
+        )
+        console.print()
+
     # Start the status again
     status.start()
 
@@ -940,6 +1108,7 @@ async def run_task_flow(status: Status, fixed_agent_id: Optional[str] = None) ->
             disk_size=load_config("disk_size"),
             storage=load_config("storage"),
             environment=get_environment_variables(),
+            services=load_config("services"),
             schedule=load_config("job_schedule"),
             setup_cmd=load_script("setup.sh"),
             run_cmd=load_script("task.sh"),
@@ -972,6 +1141,8 @@ async def run_task_flow(status: Status, fixed_agent_id: Optional[str] = None) ->
 
     if task_info.task_status == TaskStatusEnum.ON:
         console.print("- Scheduled job enabled")
+        console.print("- Note: You can disable your job by running: [bold]omega stop[/]")
+        console.print()
         if task_info.job_status != JobStatusEnum.RUNNING:
             # ask user to start now
             task_action = await ask(
@@ -1029,6 +1200,7 @@ async def run_agent_flow(status: Status):
             load_config("disk_size"),
             load_config("storage"),
             get_environment_variables(),
+            load_config("services"),
             JobTypeEnum(load_config("job_type")),
             load_script("setup.sh"),
             load_script("run.sh"),
@@ -1083,6 +1255,8 @@ async def run_agent_flow(status: Status):
 
     if agent_info.agent_status == AgentStatusEnum.BUSY:
         console.print("- Application is running")
+        console.print("- Note: You can stop your application by running: [bold]omega stop[/]")
+        console.print()
         agent_info = await inspect_agent(agent_id)
         if agent_info.job_url:
             console.print(f"Application URL: {agent_info.job_url}")
@@ -1215,6 +1389,7 @@ async def stop_task_flow(status: Status, task_id: str) -> bool:
 
     status.update("[bold cyan]Checking the scheduled job...[/]")
     task_info = await inspect_task(task_id)
+    job_type = JobTypeEnum(load_config("job_type"))
 
     # If task is not enabled, nothing to do
     if not task_info or not task_info.task_status:
@@ -1230,7 +1405,8 @@ async def stop_task_flow(status: Status, task_id: str) -> bool:
 
         # Disable task
         console.print("- Scheduled job stopped. Disabling...")
-        task_info = await api.disable_task_api(task_id, stop_agent=True)
+        stop_agent = job_type == JobTypeEnum.JOB  # if API, then don't stop agent
+        task_info = await api.disable_task_api(task_id, stop_agent=stop_agent)
 
     if task_info.task_status == TaskStatusEnum.OFF:
         console.print("- Scheduled job disabled. Syncing files...")
@@ -1239,7 +1415,8 @@ async def stop_task_flow(status: Status, task_id: str) -> bool:
     console.print("[green]Scheduled job cancelled[/]")
     console.print()
 
-    print_costs(task_info)
+    if job_type == JobTypeEnum.JOB:
+        print_costs(task_info)
 
     return True
 
@@ -1349,63 +1526,158 @@ def get_job_title(job_type: JobTypeEnum) -> str:
         return "Lab (Jupyter Notebook)"
 
 
-def detect_framework(content: str) -> Tuple[str, str]:
+def autodetect_build_commands() -> List[str]:
     """
-    Detect the framework used in the application and return appropriate commands.
-
-    Args:
-        content: Content of main.py file
-
-    Returns:
-        Tuple of (framework_name, run_command)
+    Detect build commands for the application (install dependencies)
     """
-    main_file = "main"
-    app_name = "app"
-    port = 8008
-    host = "0.0.0.0"
+    base_directory = os.getcwd()
+    requirements_txt_path = os.path.join(base_directory, "requirements.txt")
+    package_json_path = os.path.join(base_directory, "package.json")
 
-    if "from fastapi import" in content:
-        return "fastapi", f"python -m uvicorn --host {host} --port {port} {main_file}:{app_name}"
-    elif "from flask import" in content:
-        return "flask", f"python -m gunicorn -b {host}:{port} -w 3 {main_file}:{app_name}"
+    build_commands = []
+    if os.path.exists(requirements_txt_path):
+        build_commands = ["pip install --no-cache-dir -r requirements.txt"]
+    if os.path.exists(package_json_path):
+        package_manager = get_node_package_manager()
+        build_commands = [f"{package_manager} install"]
+
+    return build_commands
+
+
+def get_node_package_manager() -> str:
+    """
+    Detect package manager for Node.js
+    """
+    base_directory = os.getcwd()
+    # Check for lock files to determine package manager
+    if os.path.exists(os.path.join(base_directory, "pnpm-lock.yaml")):
+        package_manager = "pnpm"
+    elif os.path.exists(os.path.join(base_directory, "yarn.lock")):
+        package_manager = "yarn"
+    elif os.path.exists(os.path.join(base_directory, "package-lock.json")):
+        package_manager = "npm"
     else:
-        return "python", f"python {main_file}.py"
+        # Default to npm if no lock file is found
+        package_manager = "npm"
+
+    return package_manager
 
 
-async def detect_job_type() -> JobTypeEnum:
+def get_node_scripts() -> Dict[str, str]:
+    """
+    Get all scripts from package.json and detect package manager
+    """
+    base_directory = os.getcwd()
+    package_json_path = os.path.join(base_directory, "package.json")
+    if not os.path.exists(package_json_path):
+        return {}
+
+    with open(package_json_path, "r") as f:
+        package_json = json.load(f)
+
+    package_manager = get_node_package_manager()
+
+    # Return scripts with package manager prefix
+    package_json_scripts = package_json.get("scripts", {})
+    scripts = {f"{package_manager} run {k}": v for k, v in package_json_scripts.items()}
+    return scripts
+
+
+def autodetect_framework() -> str:
+    """
+    Detect the framework used in the application
+    """
+    base_directory = os.getcwd()
+    requirements_txt_path = os.path.join(base_directory, "requirements.txt")
+    package_json_path = os.path.join(base_directory, "package.json")
+
+    framework = "unknown"
+    if os.path.exists(requirements_txt_path):
+        # Python
+        # if fastapi or flask in requirements.txt, return "fastapi" or "flask"
+        with open(requirements_txt_path, "r") as f:
+            requirements_content = f.read().lower()
+        if "fastapi" in requirements_content:
+            framework = "fastapi"
+        elif "flask" in requirements_content:
+            framework = "flask"
+
+    if os.path.exists(package_json_path):
+        # Node
+        framework = "node"
+
+    return framework
+
+
+async def autodetect_run_commands() -> List[str]:
+    """
+    Detect run commands for the application
+    """
+    base_directory = os.getcwd()
+    requirements_txt_path = os.path.join(base_directory, "requirements.txt")
+    package_json_path = os.path.join(base_directory, "package.json")
+
+    run_commands = []
+    if os.path.exists(requirements_txt_path):
+        # python
+        framework = autodetect_framework()
+        main_file = "main"
+        app_name = "app"
+        port = 8008
+        host = "0.0.0.0"
+        workers = 4
+
+        if framework == "fastapi":
+            run_commands = [
+                f"python -m uvicorn --host {host} --port {port} --workers {workers} {main_file}:{app_name}"
+            ]
+
+        elif framework == "flask":
+            run_commands = [
+                f"python -m gunicorn -b {host}:{port} -w {workers} {main_file}:{app_name}"
+            ]
+        else:
+            run_commands = [f"python {main_file}.py"]
+
+    if os.path.exists(package_json_path):
+        # node
+        package_manager = get_node_package_manager()
+        default_script = f"{package_manager} run start"
+        run_commands = [default_script]
+
+    return run_commands
+
+
+def autodetect_task_commands() -> List[str]:
+    """
+    Detect commands for scheduled task
+    """
+    base_directory = os.getcwd()
+    requirements_txt_path = os.path.join(base_directory, "requirements.txt")
+    package_json_path = os.path.join(base_directory, "package.json")
+
+    task_commands = []
+    if os.path.exists(requirements_txt_path):
+        task_commands = ["python main.py"]
+    if os.path.exists(package_json_path):
+        package_manager = get_node_package_manager()
+        task_commands = [f"{package_manager} run start"]
+
+    return task_commands
+
+
+async def autodetect_job_type() -> JobTypeEnum:
     """Detect the job type based on the files in the current directory.
 
     Returns:
         JobTypeEnum: The job type.
     """
-    base_directory = os.getcwd()
 
-    # If requirements.txt exists, add pip install command to build.sh
-    requirements_txt_path = os.path.join(base_directory, "requirements.txt")
-    build_commands = []
-    if os.path.exists(requirements_txt_path):
-        build_commands = ["python -m pip install --no-cache-dir -r requirements.txt"]
-    save_script("build.sh", build_commands)
-
-    main_py_path = os.path.join(base_directory, "main.py")
-    if os.path.exists(main_py_path):
-        with open(main_py_path, "r") as f:
-            content = f.read()
-
-        # Detect framework and get run command
-        framework, run_command = detect_framework(content)
-
-        # Write run command to run.sh
-        save_script("run.sh", [run_command])
-
-        if framework in ["fastapi", "flask"]:
-            return JobTypeEnum.API
-        else:
-            return JobTypeEnum.JOB
+    framework = autodetect_framework()
+    if framework in ["fastapi", "flask", "node"]:
+        return JobTypeEnum.API
     else:
-        # For LAB type, create empty run.sh
-        save_script("run.sh")
-        return JobTypeEnum.LAB
+        return JobTypeEnum.JOB
 
 
 def get_environment_variables() -> Dict[str, str]:
@@ -1643,5 +1915,33 @@ def validate_config(config: dict) -> bool:
     return True
 
 
+def detect_package_manager() -> str:
+    """
+    Detect the primary package manager for the current project.
+    Returns:
+        str: The detected package manager ('uv', 'pip', 'pnpm', 'yarn', 'npm', or None if not detected)
+    """
+    base_directory = os.getcwd()
+
+    # Check for Python package managers
+    if os.path.exists(os.path.join(base_directory, "uv.lock")):
+        return "uv"
+    elif os.path.exists(os.path.join(base_directory, "requirements.txt")):
+        return "pip"
+
+    # Check for Node.js package managers
+    if os.path.exists(os.path.join(base_directory, "package.json")):
+        if os.path.exists(os.path.join(base_directory, "pnpm-lock.yaml")):
+            return "pnpm"
+        elif os.path.exists(os.path.join(base_directory, "yarn.lock")):
+            return "yarn"
+        elif os.path.exists(os.path.join(base_directory, "package-lock.json")):
+            return "npm"
+        else:
+            return "npm"  # Default to npm if package.json exists but no lock file
+
+    return None
+
+
 if __name__ == "__main__":
     cli()
